This function reveals the position of the true data in a parade.
Arguments
- parade
The name of an object generated using the
paradeorparade_summaryfunction.
This function reveals the position of the true data in a parade.
The name of an object generated using the parade
or parade_summary function.